@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "cfrs" "1.7.0"
+(define-package "cfrs" "20250729.1422"
   "Child-frame based read-string."
   '((emacs    "26.1")
     (dash     "2.11.0")
